@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * widget-color-combo.h - A color selector combo box
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -31,7 +31,7 @@
 #ifndef GI_COLOR_COMBO_H
 #define GI_COLOR_COMBO_H
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include "gi-combo-box.h"
 #include "gi-color-palette.h"
 
