@@ -24,7 +24,7 @@
 #ifndef GI_COMBO_BOX_H
 #define GI_COMBO_BOX_H
 
-#include <gtk/gtkhbox.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
